@@ -131,7 +131,6 @@ class ArteTV(QObject):
 
         lgg.info('arte tv list updated')
         self.categories = [(k, "") for k in self.categories_videos.keys()]
-        print(self.categories)
         self.categories.insert(0, ["arte+7", ""])
         self.clean_lists()
         self.ui.set_categories_items(self.categories)
@@ -290,12 +289,14 @@ class ArteTV(QObject):
                     item.teaser = data["teaser"]
             except KeyError:
                 pass
+
             item.duration = data["duration"]
             item.origin = ", ".join(data["country"])
             item.anno = data["date"]
             item.realisation = data["real"]
             item.actors = data["cast"]
-            print(data["country"], data["real"])
+            if not item.description:
+                self.get_item_description(item)
 
     def get_serial_item(self, item, content):
         lgg.info("Get serial item")
@@ -303,7 +304,6 @@ class ArteTV(QObject):
             data = json.loads(content)
         except Exception as why:
             lgg.info("json read error: %s" % why)
-            #print(content[:100])
             return
 
         meta = data["data"]["attributes"]["metadata"]
@@ -322,7 +322,20 @@ class ArteTV(QObject):
     def get_serial_collection(self, item, page):
         parser = SerialParser()
         parser.feed(page)
-            
+
+    def get_item_description(self, item):
+        lgg.info("Search description from player")
+        page = self.get_page_content(item.player)
+        try:
+            data = json.loads(page)
+        except Exception as why:
+            lgg.info("json read error: %s" % why)
+            return
+
+        try:
+            item.description = data["data"]["attributes"]["metadata"]["description"]
+        except Exception as why:
+            lgg.info("json keys error: %s" % why)
 
     def on_item_added(self, idx):
         """Verify the stream's urls for a video.
